# -*- encoding: utf-8 -*-

from django.test import TestCase

from bpp.jezyk_polski import warianty_zapisanego_nazwiska

class TestWariantyZapisanegoNazwiska(TestCase):
    def test_wariantyZapisanegoNazwiska(self):
        wzn = warianty_zapisanego_nazwiska

        self.assertEqual(
            list(wzn("Jan Maria", "Rokita", None)),
            ["Jan Maria Rokita",    "J[an] M[aria] Rokita",     "J. M. Rokita",
             "Jan Rokita",          "J[an] Rokita",             "J. Rokita",
             "Maria Rokita",        "M[aria] Rokita",           "M. Rokita",
             ])

        self.assertEqual(
            list(wzn("Jan Maria", "Rokita-Potocki", None)),
            ['Jan Maria Rokita-Potocki',       'Jan Maria Rokita',        'Jan Maria Potocki',
             'J[an] M[aria] Rokita-Potocki',   'J[an] M[aria] Rokita',    'J[an] M[aria] Potocki',
             'J. M. Rokita-Potocki',           'J. M. Rokita',            'J. M. Potocki',
             
             'Jan Rokita-Potocki',             'Jan Rokita',              'Jan Potocki',
             'J[an] Rokita-Potocki',           'J[an] Rokita',            'J[an] Potocki',
             'J. Rokita-Potocki',              'J. Rokita',               'J. Potocki',


             'Maria Rokita-Potocki',             'Maria Rokita',              'Maria Potocki',
             'M[aria] Rokita-Potocki',           'M[aria] Rokita',            'M[aria] Potocki',
             'M. Rokita-Potocki',              'M. Rokita',               'M. Potocki',
             ])

        self.assertEqual(
            list(wzn('Stanisław J.', 'Czuczwar', None)),
            ['Stanisław J. Czuczwar',      'S[tanisław] J. Czuczwar',         'S. J. Czuczwar',
             'Stanisław Czuczwar',         'S[tanisław] Czuczwar',            'S. Czuczwar',
             'J. Czuczwar',                'J. Czuczwar',                     'J. Czuczwar'])

        self.assertEqual(
            list(wzn('Zbigniew F.', 'Zagórski', None)),
            ['Zbigniew F. Zagórski',   'Z[bigniew] F. Zagórski',      'Z. F. Zagórski',
             'Zbigniew Zagórski',      'Z[bigniew] Zagórski',         'Z. Zagórski',
             'F. Zagórski',            'F. Zagórski',                 'F. Zagórski'])

        self.assertEqual(
            list(wzn('Jan', 'Kowalski', 'Nowak')),
            ['Jan Kowalski',        'J[an] Kowalski',       'J. Kowalski',
             'Jan Nowak',            'J[an] Nowak',          'J. Nowak'])



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-19 22:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0094_seria_wydawnicza'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='seria_wydawnicza',
            options={'verbose_name': 'seria wydawnicza', 'verbose_name_plural': 'serie wydawnicze'},
        ),
        migrations.RemoveField(
            model_name='seria_wydawnicza',
            name='e_issn',
        ),
        migrations.RemoveField(
            model_name='seria_wydawnicza',
            name='issn',
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='e_issn',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='e-ISSN'),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='issn',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='ISSN'),
        ),
    ]



from decimal import Decimal

from django.core.exceptions import ValidationError
from django.db import models, transaction
from django.db.models import CASCADE, PositiveSmallIntegerField
from model_utils import Choices

# bpp=# select distinct substr(id, 1, 2), dziedzina from import_dbf_ldy;
#  substr |                 dziedzina
# --------+--------------------------------------------
#  01     | Dziedzina nauk humanistycznych
#  02     | Dziedzina nauk inżynieryjno-technicznych
#  03     | Dziedzina nauk medycznych i nauk o zdrowiu
#  04     | Dziedzina nauk rolniczych
#  05     | Dziedzina nauk społecznych
#  06     | Dziedzina nauk ścisłych i przyrodniczych
#  07     | Dziedzina nauk teologicznych
#  08     | Dziedzina sztuki
# (8 rows)
from import_common.normalization import normalize_kod_dyscypliny

from bpp import const


def mnoznik_dla_monografii(kod_dziedziny, tryb_kalkulacji, punktacja_monografii):
    """
    § 12.
    5. W przypadku działalności naukowej prowadzonej w ramach dyscyplin naukowych
    należących do dziedziny nauk humanistycznych, dziedziny nauk społecznych i
    dziedziny nauk teologicznych całkowitą wartość punktową:

    1) monografii naukowej wynoszącą – zgodnie z przepisem ust. 2 pkt 1:
        a) 200 pkt, zwiększa się o 50%,
        b) 80 pkt, zwiększa się o 25%;

    2) redakcji naukowej monografii naukowej wynoszącą – zgodnie z przepisem ust. 3
        pkt 1 – 100 pkt, zwiększa się o 50%;

    3) rozdziału w monografii naukowej wynoszącą – zgodnie z przepisem ust. 4 pkt 1
        – 50 pkt, zwiększa się o 50%.

    :return:
    """
    if kod_dziedziny in const.WYZSZA_PUNKTACJA:

        if tryb_kalkulacji == const.TRYB_KALKULACJI.AUTORSTWO_MONOGRAFII:
            if punktacja_monografii == 200:
                return 1.5
            elif punktacja_monografii == 80:
                return 1.25

        elif tryb_kalkulacji == const.TRYB_KALKULACJI.REDAKCJA_MONOGRAFI:
            if punktacja_monografii == 100:
                return 1.5

        elif tryb_kalkulacji == const.TRYB_KALKULACJI.ROZDZIAL_W_MONOGRAFI:
            if punktacja_monografii == 50:
                return 1.5

        else:
            raise NotImplementedError(
                f"Nieobsługiwany tryb kalkulacji: {tryb_kalkulacji}"
            )

    return 1


def waliduj_format_kodu_numer(value):
    try:
        val1, val2 = (int(x) for x in value.split("."))
    except (TypeError, ValueError):
        raise ValidationError("Poprawny kod ma format LICZBA[kropka]LICZBA")

    msg = (
        "Pierwsza cyfra dziedziny nie ma odwzorowania w słowniku dziedzin w systemie BPP. "
        "Jeżeli jesteś pewny/a że ta wartośc jest poprawna, skontaktuj się z administratorem "
        "systemu. "
    )
    try:
        dziedzina = const.DZIEDZINA(val1)
    except ValueError:
        raise ValidationError(msg)

    if dziedzina not in const.DZIEDZINY:
        raise ValidationError(msg)


class KodDyscyplinyField(models.CharField):
    def __init__(self, *args, **kw):
        super().__init__(*args, **kw)
        self.validators.append(waliduj_format_kodu_numer)

    def to_python(self, value):
        return normalize_kod_dyscypliny(value)


class Dyscyplina_Naukowa(models.Model):
    kod = KodDyscyplinyField(max_length=20, unique=True)
    nazwa = models.CharField(max_length=200, unique=True)
    widoczna = models.BooleanField(default=True)

    def kod_dla_pbn(self):
        a, b = (int(x) for x in self.kod.split(".", 1))
        return int("%i%.2i" % (a, b))

    def __str__(self):
        return f"{self.nazwa} ({self.kod})"

    class Meta:
        verbose_name_plural = "dyscypliny naukowe"
        verbose_name = "dyscyplina naukowa"

    def kod_dziedziny(self):
        try:
            return int(self.kod.lstrip("0").strip().split(".")[0])
        except (ValueError, TypeError, KeyError):
            pass

    def dziedzina(self):
        kod_dziedziny = self.kod_dziedziny()
        if kod_dziedziny is not None:
            try:
                return const.DZIEDZINY.get(const.DZIEDZINA(kod_dziedziny))
            except ValueError:
                return "[niepoprawny kod]"

    def mnoznik_dla_monografi(self, tryb_kalkulacji, punktacja_monografi):
        return mnoznik_dla_monografii(
            self.kod_dziedziny(), tryb_kalkulacji, punktacja_monografi
        )


class Autor_DyscyplinaManager(models.Manager):
    @transaction.atomic
    def ukryj_nieuzywane(self):
        # Ukryj dyscypliny nieużywane
        for elem in Dyscyplina_Naukowa.objects.all():
            elem.widoczna = False
            elem.save()

        for attr in "dyscyplina_naukowa", "subdyscyplina_naukowa":
            for elem in self.all().values(attr).distinct():
                if elem[attr] is None:
                    continue

                elem = Dyscyplina_Naukowa.objects.get(pk=elem[attr])
                elem.widoczna = True
                elem.save()


class Autor_Dyscyplina(models.Model):
    rok = PositiveSmallIntegerField()
    autor = models.ForeignKey("bpp.Autor", CASCADE)

    RODZAJE_AUTORA = Choices(
        (" ", "brak danych"),
        ("N", "pracownik zaliczany do liczby N"),
        ("D", "doktorant"),
        ("Z", "inny zatrudniony"),
    )

    rodzaj_autora = models.CharField(
        max_length=1,
        choices=RODZAJE_AUTORA,
        default=" ",
    )

    wymiar_etatu = models.DecimalField(
        blank=True, null=True, decimal_places=2, max_digits=3
    )

    dyscyplina_naukowa = models.ForeignKey(
        "bpp.Dyscyplina_Naukowa", models.PROTECT, related_name="dyscyplina"
    )
    procent_dyscypliny = models.DecimalField(
        max_digits=5, decimal_places=2, null=True, blank=True
    )

    subdyscyplina_naukowa = models.ForeignKey(
        "bpp.Dyscyplina_Naukowa",
        models.PROTECT,
        related_name="subdyscyplina",
        blank=True,
        null=True,
    )
    procent_subdyscypliny = models.DecimalField(
        max_digits=5, decimal_places=2, null=True, blank=True
    )

    objects = Autor_DyscyplinaManager()

    def __str__(self):
        ret = f"przypisanie {self.autor} na rok {self.rok} do dyscypliny {self.dyscyplina_naukowa}"
        if self.subdyscyplina_naukowa_id is not None:
            ret += f" oraz {self.subdyscyplina_naukowa}"
        return ret

    class Meta:
        unique_together = [("rok", "autor")]
        verbose_name = "powiązanie autor-dyscyplina"
        verbose_name_plural = "powiązania autor-dyscyplina"

    def clean(self):
        p1 = self.procent_dyscypliny or Decimal("0.00")
        p2 = self.procent_subdyscypliny or Decimal("0.00")

        if p1 + p2 > Decimal("100.00"):
            raise ValidationError(
                {"procent_dyscypliny": "Suma procentów przekracza 100."}
            )

        if hasattr(self, "dyscyplina_naukowa") and hasattr(
            self, "subdyscyplina_naukowa"
        ):
            if self.dyscyplina_naukowa_id == self.subdyscyplina_naukowa_id:
                raise ValidationError(
                    {"subdyscyplina_naukowa": "Wpisano tą samą dyscyplinę dwukrotnie."}
                )



import os

import pytest
from django.core.files.uploadedfile import SimpleUploadedFile
from model_bakery import baker

from import_pracownikow.models import ImportPracownikow

from bpp.models import Autor, Jednostka


def testdata_xls_path_factory(suffix=""):
    return os.path.join(os.path.dirname(__file__), "", f"testdata{suffix}.xlsx")


def import_pracownikow_factory(user, path):
    i = ImportPracownikow(owner=user)
    i.plik_xls = SimpleUploadedFile(
        "import_dyscyplin_zrodel_przyklad.xlsx", open(path, "rb").read()
    )
    i.save()
    return i


@pytest.fixture
def testdata_xlsx_path():
    return testdata_xls_path_factory()


@pytest.fixture
def testdata_brak_naglowka_xlsx_path():
    return testdata_xls_path_factory("_brak_naglowka")


@pytest.fixture
def autor_z_pliku():
    return baker.make(Autor, nazwisko="Kowalski", imiona="Jan", pk=50)


@pytest.fixture
def jednostka_z_pliku():
    return baker.make(
        Jednostka,
        nazwa="Katedra i Klinika Dermatologii, Wenerologii i Dermatologii Dziecięcej",
        skrot="Kat. i Klin. Derm., Wen. i Derm. Dz.",
    )


@pytest.fixture
def baza_importu_pracownikow(autor_z_pliku, jednostka_z_pliku):
    pass


@pytest.fixture
def autor_spoza_pliku():
    return baker.make(Autor, nazwisko="Nowak", imiona="Marian", pk=100)


@pytest.fixture
def jednostka_spoza_pliku() -> Jednostka:
    return baker.make(
        Jednostka,
        nazwa="Jednostka Spozaplikowa",
        skrot="Jedn. Spoz.",
        zarzadzaj_automatycznie=True,
    )


@pytest.fixture
def import_pracownikow(admin_user, baza_importu_pracownikow, testdata_xlsx_path):
    return import_pracownikow_factory(admin_user, testdata_xlsx_path)


@pytest.fixture
def import_pracownikow_performed(import_pracownikow) -> ImportPracownikow:
    import_pracownikow.perform()
    return import_pracownikow


@pytest.fixture
def import_pracownikow_brak_naglowka(admin_user, testdata_brak_naglowka_xlsx_path):
    return import_pracownikow_factory(admin_user, testdata_brak_naglowka_xlsx_path)



from django.core.management import call_command
from django.db import transaction

from pbn_api.management.commands.util import PBNBaseCommand
from pbn_api.models import Publisher

from bpp.const import PBN_LATA
from bpp.models import Wydawca

poziom_to_points_map = {2: 200, 1: 80}
points_to_poziom_map = {200: 2, 80: 1}


class Command(PBNBaseCommand):
    def handle(self, verbosity=1, *args, **options):
        needs_mapping = False
        needs_recalc = set()

        with transaction.atomic():
            for publisher in Publisher.objects.official():

                if not publisher.wydawca_set.exists():
                    # Nie ma takiego wydawcy w bazie BPP, spróbuj go zmatchować:

                    nw = publisher.matchuj_wydawce()
                    if nw is not None:
                        if publisher.publisherName != nw.nazwa:
                            print(
                                f"0 ZWERYFIKUJ FONETYCZNE DOPASOWANIE: {publisher.publisherName} do {nw.nazwa}"
                            )
                        nw.pbn_uid = publisher
                        nw.save()

                if not publisher.wydawca_set.exists():
                    # Nie ma takiego wydawcy w bazie, utwórz go:

                    nowy_wydawca = Wydawca.objects.create(
                        nazwa=publisher.publisherName, pbn_uid=publisher
                    )
                    if verbosity > 1:
                        print(
                            f"1 Tworze nowego wydawce z MNISWID, {publisher.publisherName}"
                        )

                    for rok in PBN_LATA:
                        points = publisher.points.get(str(rok))

                        if not points:
                            # Brak punktów w PBNie za dany rok
                            continue

                        if not points["accepted"]:
                            raise NotImplementedError(
                                f"Accepted = False dla {publisher} {rok}, co dalej?"
                            )

                        poziom = points_to_poziom_map.get(points["points"])
                        assert poziom, f"Brak odpowiednika dla {points['points']}"

                        nowy_wydawca.poziom_wydawcy_set.create(rok=rok, poziom=poziom)

                    needs_mapping = True
                    continue

                # Jest już taki wydawca i ma ustawiony match z PBN. Sprawdzimy mu jego poziomy:
                for wydawca in publisher.wydawca_set.all():

                    # Nie pracujemy na aliasach
                    wydawca = wydawca.get_toplevel()

                    for rok in PBN_LATA:
                        pbn_side = publisher.points.get(str(rok))

                        wydawca_side = wydawca.poziom_wydawcy_set.filter(
                            rok=rok
                        ).first()

                        if pbn_side is not None:
                            if not pbn_side["accepted"]:
                                raise NotImplementedError(
                                    f"Accepted = False dla {publisher} {rok}, co dalej?"
                                )

                            if wydawca_side is None:
                                # Nie ma poziomu po naszej stronie dla tego rkou ,dodamy go:
                                poziom_bpp = points_to_poziom_map.get(
                                    pbn_side["points"]
                                )
                                if not poziom_bpp:
                                    raise NotImplementedError(
                                        f"Brak odpowiednika poziomu {pbn_side['points']} w mappingu"
                                    )

                                if verbosity > 1:
                                    print(
                                        f"2 Wydawca {wydawca}: dodaje poziom {poziom_bpp} za {rok} "
                                    )

                                wydawca.poziom_wydawcy_set.create(
                                    rok=rok, poziom=poziom_bpp
                                )
                                needs_recalc.add((wydawca, rok))
                                continue

                            # Są obydwa poziomy: Publisher (PBN) i Wydawca (BPP)
                            # porównaj, czy są ok:

                            wydawca_side_poziom_translated = poziom_to_points_map.get(
                                wydawca_side.poziom
                            )

                            if pbn_side["points"] != wydawca_side_poziom_translated:
                                raise NotImplementedError(
                                    f"Poziomy sie roznia dla {publisher} {rok}, co dalej?"
                                )
                        else:
                            # pbn_side is None
                            if wydawca_side is not None:
                                print(
                                    f"4 PBN nie ma poziomu a wydawca ma, co robic? {publisher} {rok}"
                                )

                            # wydawca_side is None, są równe zatem, nic nie robimy

        # To uruchamiamy poza transakcją - jeżeli były zmiany
        if needs_mapping:
            call_command("zamapuj_wydawcow")



# Generated by Django 3.0.14 on 2021-10-10 20:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0303_denorm_cleanup_cachequeue_gone"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="autor_dyscyplina",
            options={
                "verbose_name": "powiązanie autor-dyscyplina",
                "verbose_name_plural": "powiązania autor-dyscyplina",
            },
        ),
        migrations.AlterModelOptions(
            name="szablondlaopisubibliograficznego",
            options={
                "verbose_name": "powiązanie szablonu dla opisu bibliograficznego",
                "verbose_name_plural": "powiązania szablonów dla opisu bibliograficznego",
            },
        ),
    ]



# Generated by Django 2.1.7 on 2019-09-10 19:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0178_auto_20190905_2020'),
    ]

    operations = [
        migrations.AddField(
            model_name='patent',
            name='tekst_po_ostatnim_autorze',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='patent',
            name='tekst_przed_pierwszym_autorem',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='praca_doktorska',
            name='tekst_po_ostatnim_autorze',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='praca_doktorska',
            name='tekst_przed_pierwszym_autorem',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='praca_habilitacyjna',
            name='tekst_po_ostatnim_autorze',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='praca_habilitacyjna',
            name='tekst_przed_pierwszym_autorem',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='tekst_po_ostatnim_autorze',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='tekst_przed_pierwszym_autorem',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='tekst_po_ostatnim_autorze',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='tekst_przed_pierwszym_autorem',
            field=models.TextField(blank=True, null=True),
        ),
    ]



# Generated by Django 3.0.14 on 2021-08-13 22:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0283_auto_20210809_0142"),
    ]

    operations = [
        migrations.CreateModel(
            name="BppMultiseekVisibility",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(db_index=True, max_length=50, unique=True)),
                ("label", models.CharField(max_length=200)),
                (
                    "public",
                    models.BooleanField(
                        default=True, verbose_name="Widoczne dla wszystkich"
                    ),
                ),
                (
                    "authenticated",
                    models.BooleanField(
                        default=True, verbose_name="Widoczne dla zalogowanych"
                    ),
                ),
                (
                    "staff",
                    models.BooleanField(
                        default=True, verbose_name='Widoczne dla osób "w zespole"'
                    ),
                ),
                ("sort_order", models.PositiveSmallIntegerField(default=0)),
            ],
        ),
    ]



import pytest
from django.core.exceptions import ValidationError
from model_bakery import baker

from bpp.models import (
    Patent,
    Patent_Autor,
    Wydawnictwo_Ciagle,
    Wydawnictwo_Ciagle_Autor,
    Wydawnictwo_Zwarte,
    Wydawnictwo_Zwarte_Autor,
)


@pytest.mark.django_db
@pytest.mark.parametrize(
    "w",
    [
        pytest.lazy_fixture("wydawnictwo_zwarte"),
        pytest.lazy_fixture("wydawnictwo_ciagle"),
        pytest.lazy_fixture("patent"),
    ],
)
def test_autor_jednostka_afiliuje_na_obca(autor_jan_kowalski, obca_jednostka, w):
    from django.conf import settings

    assert getattr(settings, "BPP_WALIDUJ_AFILIACJE_AUTOROW", True)

    with pytest.raises(ValidationError):
        w.dodaj_autora(autor_jan_kowalski, obca_jednostka, afiliuje=True)

    obca_jednostka.skupia_pracownikow = True
    obca_jednostka.save()
    w.dodaj_autora(autor_jan_kowalski, obca_jednostka, afiliuje=True)


@pytest.mark.django_db
@pytest.mark.parametrize(
    "w,r",
    [
        (Wydawnictwo_Zwarte_Autor, Wydawnictwo_Zwarte),
        (Wydawnictwo_Ciagle_Autor, Wydawnictwo_Ciagle),
        (Patent_Autor, Patent),
    ],
)
def test_autor_jednostka_afiliuje_bug(autor_jan_kowalski, obca_jednostka, w, r):
    ri = baker.make(r)
    wi = w(autor=autor_jan_kowalski, jednostka=None, rekord=ri)
    wi.clean()



# Generated by Django 3.0.14 on 2022-04-25 01:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0316_uczelnia_jednostek_na_strone"),
    ]

    operations = [
        migrations.AddField(
            model_name="uczelnia",
            name="pokazuj_tylko_jednostki_nadrzedne",
            field=models.BooleanField(
                default=False,
                help_text="Pokazuj tylko jednostki nadrzędne na stronie prezentacji\n       "
                " danych dla użytkownika końcowego",
            ),
        ),
    ]



# Generated by Django 3.0.7 on 2020-08-05 23:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0214_auto_20200628_2344"),
    ]

    operations = [
        migrations.AddField(
            model_name="autor_dyscyplina",
            name="rodzaj_autora",
            field=models.CharField(
                choices=[
                    (" ", "brak danych"),
                    ("N", "pracownik zaliczany do liczby N"),
                    ("D", "doktorant"),
                    ("Z", "inny zatrudniony"),
                ],
                default=" ",
                max_length=1,
            ),
        ),
        migrations.AddField(
            model_name="autor_dyscyplina",
            name="wymiar_etatu",
            field=models.DecimalField(
                blank=True, decimal_places=2, max_digits=3, null=True
            ),
        ),
        migrations.AlterField(
            model_name="charakter_formalny",
            name="charakter_ogolny",
            field=models.CharField(
                choices=[
                    ("art", "Artykuł"),
                    ("ksi", "Książka"),
                    ("roz", "Rozdział"),
                    ("xxx", "Inne"),
                ],
                default="xxx",
                help_text="Charakter ogólny uzywany jest m.in. do generowania opisów bibliograficznych. Stanowi on\n        ogólne określenie rekordu, czy jest to książka, rozdział czy coś innego. ",
                max_length=3,
            ),
        ),
    ]



# Generated by Django 3.0.14 on 2021-10-27 22:39

from django.db import migrations, models

import ewaluacja2021.validators


class Migration(migrations.Migration):

    dependencies = [
        ("ewaluacja2021", "0004_importmaksymalnychslotow_ostatnia_zmiana"),
    ]

    operations = [
        migrations.AddField(
            model_name="importmaksymalnychslotow",
            name="started_on",
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="importmaksymalnychslotow",
            name="plik",
            field=models.FileField(
                upload_to="",
                validators=[
                    ewaluacja2021.validators.xlsx_header_validator(
                        columns=[
                            "Stopień / Tytuł",
                            "Nazwisko",
                            "Imię",
                            "ORCID",
                            "Dyscyplina",
                            "Uwzględniony w ewaluacji",
                            "maksymalna suma udziałów jednostkowych - wszystkie dyscypliny",
                            "maksymalna suma udziałów jednostkowych - monografie",
                        ],
                        max_header_row=100,
                    )
                ],
            ),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-19 07:52
from __future__ import unicode_literals

import django.contrib.postgres.fields.hstore
from django.contrib.postgres.operations import HStoreExtension
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0088_orcid'),
    ]

    operations = [
        HStoreExtension(),

        migrations.AddField(
            model_name='patent',
            name='legacy_data',
            field=django.contrib.postgres.fields.hstore.HStoreField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='praca_doktorska',
            name='legacy_data',
            field=django.contrib.postgres.fields.hstore.HStoreField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='praca_habilitacyjna',
            name='legacy_data',
            field=django.contrib.postgres.fields.hstore.HStoreField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='legacy_data',
            field=django.contrib.postgres.fields.hstore.HStoreField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='legacy_data',
            field=django.contrib.postgres.fields.hstore.HStoreField(blank=True, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2019-07-21 21:15

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0168_dyscyplina_w_autorzy_mat'),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0169_dyscyplina_change_trigger_cacher")
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-19 09:41
from __future__ import unicode_literals

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):
    dependencies = [
        ('bpp', '0107_poprawki_wydajnosci'),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("108_bpp_nowe_sumy_view_bug")
        )
    ]



# -*- encoding: utf-8 -*-

from django.core.management import BaseCommand
from django.db import transaction
from bpp.models import Autor, Jednostka, Wydzial, Uczelnia, Zrodlo
from bpp.system import odtworz_grupy


class Command(BaseCommand):
    help = 'Odbudowuje grupy uprawnień w sytuacji dodania nowych obiektów. ' \
           'Użyj gdy np. nie widać czegoś w Adminie, do czego użytkownik ' \
           'powinien być uprawniony.'

    @transaction.atomic
    def handle(self, *args, **options):
        odtworz_grupy()



import pytest
from django.urls import reverse

from bpp.models import Charakter_Formalny, Jezyk, Typ_KBN
from bpp.tests import (
    add_extra_autor_inline,
    fill_admin_inline,
    select_select2_autocomplete,
    show_element,
)

from django_bpp.selenium_util import wait_for_page_load


@pytest.mark.parametrize("wyd", ["ciagle", "zwarte"])
def test_autor_inline_wydawnictwo_dyscyplina(
    autor_z_dyscyplina,
    jednostka,
    rok,
    admin_browser,
    live_server,
    standard_data,
    wyd,
    zrodlo,
):
    url = reverse(f"admin:bpp_wydawnictwo_{wyd}_add")
    admin_browser.visit(live_server + url)

    admin_browser.type("tytul_oryginalny", "123")
    if wyd == "ciagle":
        select_select2_autocomplete(admin_browser, "id_zrodlo", zrodlo.nazwa)
    admin_browser.type("rok", str(rok))

    show_element(admin_browser, admin_browser.find_by_name("charakter_formalny"))
    admin_browser.select("charakter_formalny", Charakter_Formalny.objects.first().pk)
    admin_browser.select("jezyk", Jezyk.objects.first().pk)
    show_element(admin_browser, admin_browser.find_by_name("typ_kbn"))
    admin_browser.select("typ_kbn", Typ_KBN.objects.first().pk)

    add_extra_autor_inline(admin_browser)
    fill_admin_inline(
        admin_browser,
        autor_z_dyscyplina.autor,
        jednostka,
        "123 foo",
        # Nie trzeba tego podawac bo dyscyplina sama 'wskoczy'
        #     dyscyplina=autor_z_dyscyplina.dyscyplina_naukowa,
    )

    with wait_for_page_load(admin_browser):
        admin_browser.find_by_name("_continue").click()

    assert "dodany pomyślnie" in admin_browser.html



"""
Profile użytkowników serwisu BPP
"""

from django.db import models
from django.dispatch import receiver
from django_auth_ldap.backend import populate_user

from django.contrib.auth.models import AbstractUser, UserManager

from django.utils.functional import cached_property
from django.utils.itercompat import is_iterable

from bpp.const import PUSTY_ADRES_EMAIL
from bpp.models import ModelZAdnotacjami


class BppUserManager(UserManager):
    model = "bpp.BppUser"


class BppUser(AbstractUser, ModelZAdnotacjami):
    active_charmap_tab = models.IntegerField(default=0)

    per_page = models.IntegerField(
        "Ilość wyświetlanych rekordów na stronie", default=20
    )

    multiseek_format = models.CharField(
        "Ostatnio wybrany format wyświetlania w Multiseeku",
        max_length=200,
        null=True,
        blank=True,
    )

    multiseek_order_1 = models.CharField(
        "Ostatnio wybrane pole sortowania w Multiseeku",
        max_length=200,
        null=True,
        blank=True,
    )

    pbn_token = models.CharField(max_length=128, null=True, blank=True)

    class Meta:
        app_label = "bpp"
        verbose_name = "użytkownik"
        verbose_name_plural = "użytkownicy"

    objects = BppUserManager()

    @cached_property
    def cached_groups(self):
        return self.groups.all()


# Uzupełnianie pól użytkownika na bazie LDAP:


@receiver(populate_user)
def populate_bppuser(user, ldap_user, **kwargs):

    # Populate the Django user from the LDAP directory.

    AUTH_LDAP_USER_ATTR_MAP = {
        "first_name": ("givenName", "BrakImieniaWActiveDirectory"),
        "last_name": ("sn", "BrakNazwiskaWActiveDirectory"),
        "email": ("mail", PUSTY_ADRES_EMAIL),
    }

    for attr, value in AUTH_LDAP_USER_ATTR_MAP.items():
        ldap_attr, default = value
        ldap_value = ldap_user.attrs.get(ldap_attr, value)

        if is_iterable(ldap_value):
            ldap_value = " ".join([str(x) for x in ldap_value])
        setattr(user, attr, ldap_value)

    user.is_active = True

    # Zresetuj uprawnienia superużytkownika i 'w zespole' dla użytkowników
    # autoryzujących się po LDAP:
    user.is_superuser = False
    user.is_staff = False



from adminsortable2.admin import SortableAdminMixin

from django.contrib import admin

from bpp.models import BppMultiseekVisibility


@admin.register(BppMultiseekVisibility)
class BppMulitiseekVisibilityAdmin(SortableAdminMixin, admin.ModelAdmin):
    list_display = ["label", "public", "authenticated", "staff", "sort_order"]
    list_filter = ["public", "authenticated", "staff"]
    readonly_fields = ["label", "field_name", "sort_order"]
    fields = ["label", "field_name", "public", "authenticated", "staff"]
    search_fields = ["label", "field_name"]

    list_per_page = 150

    def has_add_permission(self, request):
        return False



# -*- encoding: utf-8 -*-
from crispy_forms.helper import FormHelper
from crispy_forms_foundation.layout import Layout, Fieldset, Submit
from django import forms

from integrator2.models.lista_ministerialna import ListaMinisterialnaIntegration


class FormListaMinisterialna(forms.ModelForm):

    class Meta:
        model = ListaMinisterialnaIntegration
        fields = ['file', 'year']

    def __init__(self, *args, **kw):
        super(FormListaMinisterialna, self).__init__(*args, **kw)
        helper = FormHelper(self)
        helper.form_class = "custom"
        helper.layout = Layout(
            Fieldset(
                'Dodaj plik',
                'file', 'year',
                Submit('submit', 'Wyślij', css_id='id_submit')))
        self.helper = helper



def validate_file_extension_pdf(value):
    import os

    from django.core.exceptions import ValidationError

    ext = os.path.splitext(value.name)[1]  # [0] returns path+filename
    valid_extensions = [
        ".pdf",
    ]
    if not ext.lower() in valid_extensions:
        raise ValidationError(
            "Nieobsługiwany format pliku. Prosimy o pliki w formacie PDF."
        )



# Generated by Django 3.0.11 on 2021-02-02 07:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0235_auto_20210125_0042"),
        ("bpp", "0235_auto_20210201_1305"),
    ]

    operations = []



"""Resources -- zasoby -- dla modułu django-import-export

Klasy określające w jaki sposób dane są eksportowane z systemu.
"""
from django.urls import reverse
from import_export import resources
from import_export.fields import Field

from django.contrib.sites.models import Site

from bpp.models import Autor, Wydawnictwo_Ciagle, Wydawnictwo_Zwarte

WYDAWNICTWO_TYPOWE_EXCLUDES = [
    "tekst_przed_pierwszym_autorem",
    "tekst_po_ostatnim_autorze",
    "search_index",
    "tytul_oryginalny_sort",
    "legacy_data",
    "cached_punkty_dyscyplin",
    "opis_bibliograficzny_autorzy_cache",
    "slug",
    "autorzy",
]

WYDAWNICTWO_TYPOWY_EXPORT_ORDER = [
    "id",
    "tytul_oryginalny",
    "pbn_url",
    "bpp_strona_url",
    "bpp_admin_url",
    "tytul",
    "rok",
    "ostatnio_zmieniony",
]


class Wydawnictwo_ResourceBase(resources.ModelResource):
    jezyk = Field(attribute="jezyk__skrot")
    jezyk_alt = Field(attribute="jezyk_alt__skrot")
    jezyk_orig = Field(attribute="jezyk_orig__skrot")
    charakter_formalny = Field(attribute="charakter_formalny__nazwa")
    status_korekty = Field(attribute="status_korekty__nazwa")
    typ_kbn = Field(attribute="typ_kbn__nazwa")
    openaccess_wersja_tekstu = Field(attribute="openaccess_wersja_tekstu__nazwa")
    openaccess_licencja = Field(attribute="openaccess_licencja__nazwa")
    openaccess_czas_publikacji = Field(attribute="openaccess_czas_publikacji__nazwa")
    openaccess_tryb_dostepu = Field(attribute="openaccess_tryb_dostepu__nazwa")
    informacja_z = Field(attribute="informacja_z__nazwa")

    pbn_url = Field(attribute="pbn_uid")
    bpp_strona_url = Field(attribute="pk")
    bpp_admin_url = Field(attribute="pk")

    def dehydrate_pbn_url(self, obj):
        pbn_uid_id = getattr(obj, "pbn_uid_id", None)
        if pbn_uid_id:
            return obj.pbn_uid.link_do_pbn()

    def get_site_url(self):
        return "https://" + Site.objects.all().first().domain

    def dehydrate_bpp_strona_url(self, obj):
        return self.get_site_url() + reverse(
            "bpp:browse_praca", args=(obj._meta.model_name, obj.pk)
        )

    def dehydrate_bpp_admin_url(self, obj):
        return self.get_site_url() + reverse(
            "admin:{m.app_label}_{m.model_name}_change".format(m=obj._meta),
            args=[obj.pk],
        )


class Wydawnictwo_ZwarteResource(Wydawnictwo_ResourceBase):
    class Meta:
        model = Wydawnictwo_Zwarte
        exclude = WYDAWNICTWO_TYPOWE_EXCLUDES
        export_order = WYDAWNICTWO_TYPOWY_EXPORT_ORDER


class Wydawnictwo_CiagleResource(Wydawnictwo_ResourceBase):
    zrodlo = Field(attribute="zrodlo__nazwa")

    class Meta:
        model = Wydawnictwo_Ciagle
        exclude = WYDAWNICTWO_TYPOWE_EXCLUDES
        export_order = WYDAWNICTWO_TYPOWY_EXPORT_ORDER


class AutorResource(resources.ModelResource):
    aktualna_jednostka = Field(attribute="aktualna_jednostka__nazwa")
    aktualna_funkcja = Field(attribute="aktualna_funkcja__nazwa")
    tytul = Field(attribute="tytul__skrot")

    def dehydrate_jednostki(self, obj):
        if obj.jednostki.exists():
            return ", ".join(obj.jednostki.values_list("nazwa", flat=True))

    class Meta:
        model = Autor
        export_order = ["nazwisko", "imiona", "poprzednie_nazwiska"]
        exclude = ["search", "slug", "sort", "expertus_id", "pbn_id"]



# Generated by Django 2.1.13 on 2019-11-03 14:05

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='Aut',
            fields=[
                ('idt_aut', models.TextField(primary_key=True, serialize=False)),
                ('imiona', models.TextField(blank=True, null=True)),
                ('nazwisko', models.TextField(blank=True, null=True)),
                ('ref', models.TextField(blank=True, null=True)),
                ('kad_nr', models.TextField(blank=True, null=True)),
                ('tel', models.TextField(blank=True, null=True)),
                ('email', models.TextField(blank=True, null=True)),
                ('www', models.TextField(blank=True, null=True)),
                ('imiona_bz', models.TextField(blank=True, null=True)),
                ('nazwisk_bz', models.TextField(blank=True, null=True)),
                ('tytul', models.TextField(blank=True, null=True)),
                ('stanowisko', models.TextField(blank=True, null=True)),
                ('prac_od', models.TextField(blank=True, null=True)),
                ('dat_zwol', models.TextField(blank=True, null=True)),
                ('fg', models.TextField(blank=True, null=True)),
                ('dop', models.TextField(blank=True, null=True)),
                ('nr_ewid', models.TextField(blank=True, null=True)),
                ('kad_s_jed', models.TextField(blank=True, null=True)),
                ('pbn_id', models.TextField(blank=True, null=True)),
                ('res_id', models.TextField(blank=True, null=True)),
                ('scop_id', models.TextField(blank=True, null=True)),
                ('orcid_id', models.TextField(blank=True, null=True)),
                ('exp_id', models.TextField(blank=True, null=True)),
                ('polon_id', models.TextField(blank=True, null=True)),
                ('usos_id', models.TextField(blank=True, null=True)),
                ('udf_id', models.TextField(blank=True, null=True)),
                ('control', models.TextField(blank=True, null=True)),
                ('uwagi', models.TextField(blank=True, null=True)),
                ('graf', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'zaimportowany autor',
                'verbose_name_plural': 'zaimportowani autorzy',
                'db_table': 'import_dbf_aut',
                'ordering': ('nazwisko', 'imiona'),
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='B_A',
            fields=[
                ('id', models.IntegerField(primary_key=True, serialize=False)),
                ('lp', models.TextField(blank=True, null=True)),
                ('wspz', models.TextField(blank=True, null=True)),
                ('pkt_dod', models.TextField(blank=True, null=True)),
                ('wspz2', models.TextField(blank=True, null=True)),
                ('pkt2_dod', models.TextField(blank=True, null=True)),
                ('afiliacja', models.TextField(blank=True, null=True)),
                ('odp', models.TextField(blank=True, null=True)),
                ('study_ga', models.TextField(blank=True, null=True)),
                ('tytul', models.TextField(blank=True, null=True)),
                ('stanowisko', models.TextField(blank=True, null=True)),
                ('uwagi', models.TextField(blank=True, null=True)),
                ('object_id', models.PositiveIntegerField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_b_a',
                'ordering': ('idt__tytul_or_s', 'lp'),
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='B_B',
            fields=[
                ('idt', models.TextField(primary_key=True, serialize=False)),
                ('lp', models.TextField(blank=True, null=True)),
                ('idt_bazy', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_b_b',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='B_E',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('idt', models.IntegerField()),
                ('lp', models.TextField(blank=True, null=True)),
                ('idt_eng', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_b_e',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='B_L',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('idt', models.IntegerField()),
                ('idt_l', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_b_l',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='B_N',
            fields=[
                ('idt', models.TextField(primary_key=True, serialize=False)),
                ('lp', models.TextField(blank=True, null=True)),
                ('idt_pbn', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_b_n',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='B_P',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('idt', models.IntegerField()),
                ('lp', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_b_p',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='B_U',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('comm', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'zaimportowane dane OA rekordu',
                'verbose_name_plural': 'zaimportowane dane OA rekordow',
                'db_table': 'import_dbf_b_u',
                'ordering': ('idt', 'comm'),
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Dys',
            fields=[
                ('orcid_id', models.TextField(primary_key=True, serialize=False)),
                ('a_n', models.TextField(blank=True, null=True)),
                ('a_w_etatu', models.TextField(blank=True, null=True)),
                ('a_dysc_1', models.TextField(blank=True, null=True)),
                ('a_dysc_2', models.TextField(blank=True, null=True)),
                ('a_dysc_1_e', models.TextField(blank=True, null=True)),
                ('a_dysc_2_e', models.TextField(blank=True, null=True)),
                ('b_n', models.TextField(blank=True, null=True)),
                ('b_w_etatu', models.TextField(blank=True, null=True)),
                ('b_dysc_1', models.TextField(blank=True, null=True)),
                ('b_dysc_2', models.TextField(blank=True, null=True)),
                ('b_dysc_1_e', models.TextField(blank=True, null=True)),
                ('b_dysc_2_e', models.TextField(blank=True, null=True)),
                ('c_n', models.TextField(blank=True, null=True)),
                ('c_w_etatu', models.TextField(blank=True, null=True)),
                ('c_dysc_1', models.TextField(blank=True, null=True)),
                ('c_dysc_2', models.TextField(blank=True, null=True)),
                ('c_dysc_1_e', models.TextField(blank=True, null=True)),
                ('c_dysc_2_e', models.TextField(blank=True, null=True)),
                ('d_n', models.TextField(blank=True, null=True)),
                ('d_w_etatu', models.TextField(blank=True, null=True)),
                ('d_dysc_1', models.TextField(blank=True, null=True)),
                ('d_dysc_2', models.TextField(blank=True, null=True)),
                ('d_dysc_1_e', models.TextField(blank=True, null=True)),
                ('d_dysc_2_e', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'zaimportowana dyscyplina pracownika',
                'verbose_name_plural': 'zaimportowane dyscypliny pracowników',
                'db_table': 'import_dbf_dys',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Ext',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('cont', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_ext',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Ixb',
            fields=[
                ('idt_bazy', models.TextField(primary_key=True, serialize=False)),
                ('baza', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'zaimportowana baza',
                'verbose_name_plural': 'zaimportowane bazy',
                'db_table': 'import_dbf_ixb',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Ixe',
            fields=[
                ('idt_eng', models.TextField(primary_key=True, serialize=False)),
                ('haslo', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'zaimportowane hasło naukowe',
                'verbose_name_plural': 'zaimportowane hasła naukowe',
                'db_table': 'import_dbf_ixe',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Ixn',
            fields=[
                ('idt_pbn', models.TextField(blank=True, primary_key=True, serialize=False)),
                ('pbn', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'zaimportowany identyfikator PBN',
                'verbose_name_plural': 'zaimportowane identyfikatory PBN',
                'db_table': 'import_dbf_ixn',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Ixp',
            fields=[
                ('idt_pol', models.TextField(primary_key=True, serialize=False)),
                ('haslo', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_ixp',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='J_H',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('rok', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'zaimportowany rekord historii jednostek',
                'verbose_name_plural': 'zaimportowane rekordy historii jednostek',
                'db_table': 'import_dbf_j_h',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Jed',
            fields=[
                ('idt_jed', models.TextField(primary_key=True, serialize=False)),
                ('nr', models.TextField(blank=True, null=True)),
                ('skrot', models.TextField(blank=True, null=True)),
                ('nazwa', models.TextField(blank=True, null=True)),
                ('wyd_skrot', models.TextField(blank=True, null=True)),
                ('sort', models.TextField(blank=True, null=True)),
                ('to_print', models.TextField(blank=True, null=True)),
                ('to_print2', models.TextField(blank=True, null=True)),
                ('to_print3', models.TextField(blank=True, null=True)),
                ('to_print4', models.TextField(blank=True, null=True)),
                ('to_print5', models.TextField(blank=True, null=True)),
                ('email', models.TextField(blank=True, null=True)),
                ('www', models.TextField(blank=True, null=True)),
                ('id_u', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_jed',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Jer',
            fields=[
                ('nr', models.TextField(primary_key=True, serialize=False)),
                ('od_roku', models.TextField(blank=True, null=True)),
                ('skrot', models.TextField(blank=True, null=True)),
                ('nazwa', models.TextField(blank=True, null=True)),
                ('wyd_skrot', models.TextField(blank=True, null=True)),
                ('id_u', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_jer',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Jez',
            fields=[
                ('skrot', models.TextField(primary_key=True, serialize=False)),
                ('nazwa', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'zaimportowany język',
                'verbose_name_plural': 'zaimportowane języki',
                'db_table': 'import_dbf_jez',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Kad',
            fields=[
                ('nr', models.TextField(primary_key=True, serialize=False)),
                ('na', models.TextField(blank=True, null=True)),
                ('im1', models.TextField(blank=True, null=True)),
                ('im2', models.TextField(blank=True, null=True)),
                ('s_jed', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_kad',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Kbn',
            fields=[
                ('idt_kbn', models.TextField(primary_key=True, serialize=False)),
                ('skrot', models.TextField(blank=True, null=True)),
                ('nazwa', models.TextField(blank=True, null=True)),
                ('to_print', models.TextField(blank=True, null=True)),
                ('to_print2', models.TextField(blank=True, null=True)),
                ('to_print3', models.TextField(blank=True, null=True)),
                ('to_print4', models.TextField(blank=True, null=True)),
                ('to_print5', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'zaimportowany typ KBN',
                'verbose_name_plural': 'zaimportowane typy KBN',
                'db_table': 'import_dbf_kbn',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Kbr',
            fields=[
                ('idt_kbr', models.TextField(primary_key=True, serialize=False)),
                ('skrot', models.TextField(blank=True, null=True)),
                ('nazwa', models.TextField(blank=True, null=True)),
                ('to_print', models.TextField(blank=True, null=True)),
                ('to_print2', models.TextField(blank=True, null=True)),
                ('to_print3', models.TextField(blank=True, null=True)),
                ('to_print4', models.TextField(blank=True, null=True)),
                ('to_print5', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'zaimportowany rekord KBR',
                'verbose_name_plural': 'zaimportowane rekordy KBR',
                'db_table': 'import_dbf_kbr',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Ldy',
            fields=[
                ('id', models.TextField(primary_key=True, serialize=False)),
                ('dziedzina', models.TextField(blank=True, null=True)),
                ('dyscyplina', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'zaimportowana dziedzina',
                'verbose_name_plural': 'zaimportowane dziedziny',
                'db_table': 'import_dbf_ldy',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Lis',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('rok', models.TextField(blank=True, null=True)),
                ('kategoria', models.TextField(blank=True, null=True)),
                ('numer', models.TextField(blank=True, null=True)),
                ('tytul', models.TextField(blank=True, null=True)),
                ('issn', models.TextField(blank=True, null=True)),
                ('eissn', models.TextField(blank=True, null=True)),
                ('punkty', models.TextField(blank=True, null=True)),
                ('sobowtor', models.TextField(blank=True, null=True)),
                ('errissn', models.TextField(blank=True, null=True)),
                ('dblissn', models.TextField(blank=True, null=True)),
                ('dbltitul', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'zaimportowana lista wydawców',
                'verbose_name_plural': 'zaimportowane listy wydawców',
                'db_table': 'import_dbf_lis',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Loc',
            fields=[
                ('ident', models.TextField(primary_key=True, serialize=False)),
                ('ext', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_loc',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Pba',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('idt', models.TextField(blank=True, null=True)),
                ('idt_pbn', models.TextField(blank=True, null=True)),
                ('wyd_skrot', models.TextField(blank=True, null=True)),
                ('date', models.TextField(blank=True, null=True)),
                ('category', models.TextField(blank=True, null=True)),
                ('details', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_pba',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Pbb',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('rep_f_name', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_pbb',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Pbc',
            fields=[
                ('idt', models.TextField(primary_key=True, serialize=False)),
                ('wyd_skrot', models.TextField(blank=True, null=True)),
                ('date', models.TextField(blank=True, null=True)),
                ('category', models.TextField(blank=True, null=True)),
                ('details', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_pbc',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Pbd',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('rep_f_name', models.TextField(blank=True, null=True)),
                ('field_ignore_me', models.TextField(blank=True, db_column='_ignore_me', null=True)),
            ],
            options={
                'db_table': 'import_dbf_pbd',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Poz',
            fields=[
                ('id', models.IntegerField(primary_key=True, serialize=False)),
                ('kod_opisu', models.TextField(blank=True, null=True)),
                ('lp', models.PositiveSmallIntegerField()),
                ('tresc', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'zaimportowany opis rekordu',
                'verbose_name_plural': 'zaimportowane opisy rekordow',
                'db_table': 'import_dbf_poz',
                'ordering': ('idt', 'kod_opisu', 'lp'),
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Pub',
            fields=[
                ('idt_pub', models.TextField(primary_key=True, serialize=False)),
                ('skrot', models.TextField(blank=True, null=True)),
                ('nazwa', models.TextField(blank=True, null=True)),
                ('to_print', models.TextField(blank=True, null=True)),
                ('to_print2', models.TextField(blank=True, null=True)),
                ('to_print3', models.TextField(blank=True, null=True)),
                ('to_print4', models.TextField(blank=True, null=True)),
                ('to_print5', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'zaimportowany charakter publikacji',
                'verbose_name_plural': 'zaimportowane charaktery publikacji',
                'db_table': 'import_dbf_pub',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Rtf',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('idt', models.TextField(blank=True, null=True)),
                ('lp', models.TextField(blank=True, null=True)),
                ('len', models.TextField(blank=True, null=True)),
                ('rtf', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_rtf',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='S_B',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('idt_sci', models.TextField(blank=True, null=True)),
                ('cit', models.TextField(blank=True, null=True)),
                ('doi', models.TextField(blank=True, null=True)),
                ('del_field', models.TextField(blank=True, db_column='del', null=True)),
                ('redaktor', models.TextField(blank=True, null=True)),
                ('dat_akt', models.TextField(blank=True, null=True)),
                ('autocyt', models.TextField(blank=True, null=True)),
                ('ut', models.TextField(blank=True, null=True)),
                ('ut0', models.TextField(blank=True, null=True)),
                ('uwagi', models.TextField(blank=True, null=True)),
                ('field_ignore_me', models.TextField(blank=True, db_column='_ignore_me', null=True)),
            ],
            options={
                'db_table': 'import_dbf_s_b',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Sci',
            fields=[
                ('idt_sci', models.TextField(primary_key=True, serialize=False)),
                ('au', models.TextField(blank=True, null=True)),
                ('ti', models.TextField(blank=True, null=True)),
                ('src', models.TextField(blank=True, null=True)),
                ('ye', models.TextField(blank=True, null=True)),
                ('cont', models.TextField(blank=True, null=True)),
                ('ut', models.TextField(blank=True, null=True)),
                ('field_ignore_me', models.TextField(blank=True, db_column='_ignore_me', null=True)),
            ],
            options={
                'db_table': 'import_dbf_sci',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Ses',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('redaktor', models.TextField(blank=True, null=True)),
                ('file', models.TextField(blank=True, null=True)),
                ('login_t', models.TextField(blank=True, null=True)),
                ('logout_t', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_ses',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Sys',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ver', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'zaimportowana wersja bazy',
                'verbose_name_plural': 'zaimportowane wersje bazy',
                'db_table': 'import_dbf_sys',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Usi',
            fields=[
                ('idt_usi', models.IntegerField(primary_key=True, serialize=False)),
                ('usm_f', models.TextField(blank=True, null=True)),
                ('usm_sf', models.TextField(blank=True, null=True)),
                ('skrot', models.TextField(blank=True, null=True)),
                ('nazwa', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'zaimportowane źródło',
                'verbose_name_plural': 'zaimportowane źródła',
                'db_table': 'import_dbf_usi',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Wsx',
            fields=[
                ('idt_wsx', models.TextField(primary_key=True, serialize=False)),
                ('skrot', models.TextField(blank=True, null=True)),
                ('nazwa', models.TextField(blank=True, null=True)),
                ('wsp', models.TextField(blank=True, null=True)),
                ('field_ignore_me', models.TextField(blank=True, db_column='_ignore_me', null=True)),
            ],
            options={
                'db_table': 'import_dbf_wsx',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Wsy',
            fields=[
                ('idt_wsy', models.TextField(primary_key=True, serialize=False)),
                ('skrot', models.TextField(blank=True, null=True)),
                ('nazwa', models.TextField(blank=True, null=True)),
                ('wsp', models.TextField(blank=True, null=True)),
                ('field_ignore_me', models.TextField(blank=True, db_column='_ignore_me', null=True)),
            ],
            options={
                'db_table': 'import_dbf_wsy',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Wx2',
            fields=[
                ('idt_wsx', models.TextField(primary_key=True, serialize=False)),
                ('skrot', models.TextField(blank=True, null=True)),
                ('nazwa', models.TextField(blank=True, null=True)),
                ('wsp', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'import_dbf_wx2',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Wyd',
            fields=[
                ('idt_wyd', models.TextField(primary_key=True, serialize=False)),
                ('skrot', models.TextField(blank=True, null=True)),
                ('nazwa', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'zaimportowany wydział',
                'verbose_name_plural': 'zaimportowane wydzialy',
                'db_table': 'import_dbf_wyd',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Bib',
            fields=[
                ('idt', models.IntegerField(primary_key=True, serialize=False)),
                ('tytul_or', models.TextField(blank=True, null=True)),
                ('title', models.TextField(blank=True, null=True)),
                ('zrodlo', models.TextField(blank=True, null=True)),
                ('szczegoly', models.TextField(blank=True, null=True)),
                ('uwagi', models.TextField(blank=True, null=True)),
                ('charakter', models.TextField(blank=True, null=True)),
                ('impact', models.TextField(blank=True, null=True)),
                ('redakcja', models.TextField(blank=True, null=True)),
                ('status', models.TextField(blank=True, null=True)),
                ('rok', models.TextField(blank=True, null=True)),
                ('sort', models.TextField(blank=True, null=True)),
                ('sort2', models.TextField(blank=True, null=True)),
                ('export', models.TextField(blank=True, null=True)),
                ('import_field', models.TextField(blank=True, db_column='import', null=True)),
                ('naz_imie', models.TextField(blank=True, null=True)),
                ('redaktor', models.TextField(blank=True, null=True)),
                ('redaktor0', models.TextField(blank=True, null=True)),
                ('tytul_or_s', models.TextField(blank=True, null=True)),
                ('title_s', models.TextField(blank=True, null=True)),
                ('zrodlo_s', models.TextField(blank=True, null=True)),
                ('szczegol_s', models.TextField(blank=True, null=True)),
                ('mem_fi_ext', models.TextField(blank=True, null=True)),
                ('dat_akt', models.TextField(blank=True, null=True)),
                ('kbn', models.TextField(blank=True, null=True)),
                ('kbr', models.TextField(blank=True, null=True)),
                ('afiliowana', models.TextField(blank=True, null=True)),
                ('recenzowan', models.TextField(blank=True, null=True)),
                ('jezyk', models.TextField(blank=True, null=True)),
                ('jezyk2', models.TextField(blank=True, null=True)),
                ('punkty_kbn', models.TextField(blank=True, db_column='pk', null=True)),
                ('x_skrot', models.TextField(blank=True, null=True)),
                ('wspx', models.TextField(blank=True, null=True)),
                ('x2_skrot', models.TextField(blank=True, null=True)),
                ('wspx2', models.TextField(blank=True, null=True)),
                ('y_skrot', models.TextField(blank=True, null=True)),
                ('wspy', models.TextField(blank=True, null=True)),
                ('wspq', models.TextField(blank=True, null=True)),
                ('ic', models.TextField(blank=True, null=True)),
                ('rok_inv', models.TextField(blank=True, null=True)),
                ('link', models.TextField(blank=True, null=True)),
                ('lf', models.TextField(blank=True, null=True)),
                ('rok_punkt', models.TextField(blank=True, null=True)),
                ('form', models.TextField(blank=True, null=True)),
                ('k_z', models.TextField(blank=True, null=True)),
                ('uwagi2', models.TextField(blank=True, null=True)),
                ('dat_utw', models.TextField(blank=True, null=True)),
                ('pun_wl', models.TextField(blank=True, null=True)),
                ('study_gr', models.TextField(blank=True, null=True)),
                ('sort_fixed', models.TextField(blank=True, null=True)),
                ('zaznacz_field', models.TextField(blank=True, db_column='zaznacz_', null=True)),
                ('idt2', models.TextField(blank=True, null=True)),
                ('pun_max', models.TextField(blank=True, null=True)),
                ('pun_erih', models.TextField(blank=True, null=True)),
                ('kwartyl', models.TextField(blank=True, null=True)),
                ('issn', models.TextField(blank=True, null=True)),
                ('eissn', models.TextField(blank=True, null=True)),
                ('wok_id', models.TextField(blank=True, null=True)),
                ('sco_id', models.TextField(blank=True, null=True)),
                ('mnsw_fixed', models.TextField(blank=True, null=True)),
                ('liczba_aut', models.TextField(blank=True, null=True)),
                ('pro_p_wydz', models.TextField(blank=True, null=True)),
                ('snip', models.TextField(blank=True, null=True)),
                ('sjr', models.TextField(blank=True, null=True)),
                ('cites', models.TextField(blank=True, null=True)),
                ('if5', models.TextField(blank=True, null=True)),
                ('lis_numer', models.TextField(blank=True, null=True)),
                ('object_id', models.PositiveIntegerField(blank=True, null=True)),
                ('analyzed', models.BooleanField(default=False)),
                ('content_type', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='contenttypes.ContentType')),
            ],
            options={
                'verbose_name': 'zaimportowany rekord bibliografi',
                'verbose_name_plural': 'zaimportowane rekordy bibliografi',
                'db_table': 'import_dbf_bib',
            },
        ),
        migrations.CreateModel(
            name='Bib_Desc',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('elem_id', models.PositiveSmallIntegerField(db_index=True)),
                ('value', django.contrib.postgres.fields.jsonb.JSONField()),
                ('source', models.CharField(max_length=10)),
                ('idt', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='import_dbf.Bib')),
            ],
            options={
                'ordering': ('idt', 'source'),
            },
        ),
    ]



# Generated by Django 3.0.11 on 2021-03-08 07:39

from decimal import Decimal

import django.core.validators
from django.db import migrations, models

import bpp.models.uczelnia


class Migration(migrations.Migration):

    dependencies = [
        ("raport_slotow", "0007_auto_20210130_1407"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="raportslotowuczelnia",
            options={},
        ),
        migrations.AddField(
            model_name="raportslotowuczelnia",
            name="akcja",
            field=models.CharField(
                choices=[
                    ("slot", "do wielkości slotu"),
                    ("wszystko", "wszystkie prace"),
                ],
                default="slot",
                max_length=10,
            ),
        ),
        migrations.AlterField(
            model_name="raportslotowuczelnia",
            name="do_roku",
            field=models.IntegerField(
                default=bpp.models.uczelnia.UczelniaManager.do_roku_default
            ),
        ),
        migrations.AlterField(
            model_name="raportslotowuczelnia",
            name="pokazuj_zerowych",
            field=models.BooleanField(
                default=False,
                help_text="Autor z zerowym slotem to autor, który ma na zadany okres czasu zadeklarowane dyscypliny,\n        ale nie posiada żadnych punktowanych prac w tych dyscyplinach. Jeżeli jednoczesnie podasz parametr\n         'minimalny PK' dla tego raportu, to prace z PK poniżej tego progu zostaną potraktowane jako \"zerowe\"\n         czyli bez punktacji. ",
                verbose_name="Dołączaj autorów z zerowymi slotami",
            ),
        ),
        migrations.AlterField(
            model_name="raportslotowuczelnia",
            name="slot",
            field=models.DecimalField(
                decimal_places=4,
                default=Decimal("1"),
                max_digits=7,
                validators=[django.core.validators.MaxValueValidator(20)],
            ),
        ),
    ]



VERSION = "202210.1089"

if __name__ == "__main__":
    import sys

    OUTPUT = VERSION

    if "--json" in sys.argv:
        import json

        OUTPUT = json.dumps({"VERSION": VERSION})

    sys.stdout.write(OUTPUT)



# Generated by Django 2.2.7 on 2020-01-06 15:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('celeryui', '0002_django110_py3k'),
    ]

    operations = [
        migrations.RunSQL("""
        drop index if exists celeryui_report_uid_like;
        alter table celeryui_report alter column uid type uuid using uid::uuid;
        create index on celeryui_report(uid);
        """, None, [
            migrations.AlterField(
                model_name='Report',
                name='uuid',
                field=models.UUIDField(unique=True, editable=False, blank=True, db_index=True),
            ),
        ]),
    ]



"""
Źródła.
"""
from autoslug import AutoSlugField
from django.db import models
from django.db.models import CASCADE, SET_NULL
from django.urls.base import reverse

from django.contrib.postgres.search import SearchVectorField as VectorField

from bpp import const
from bpp.fields import DOIField, YearField
from bpp.jezyk_polski import czasownik_byc
from bpp.models import LinkDoPBNMixin, ModelZKwartylami
from bpp.models.abstract import (
    ModelPunktowanyBaza,
    ModelZAdnotacjami,
    ModelZISSN,
    ModelZNazwa,
)
from bpp.models.system import Jezyk
from bpp.util import FulltextSearchMixin


class Rodzaj_Zrodla(ModelZNazwa):
    class Meta:
        verbose_name = "rodzaj źródła"
        verbose_name_plural = "rodzaje źródeł"
        app_label = "bpp"


class Zasieg_Zrodla(ModelZNazwa):
    class Meta:
        verbose_name = "zasięg źródła"
        verbose_name_plural = "zasięg źródeł"
        app_label = "bpp"


class Redakcja_Zrodla(models.Model):
    """Informacja o tym, że ktoś jest redaktorem danego źródła - w latach,
    od - do."""

    zrodlo = models.ForeignKey("bpp.Zrodlo", CASCADE)
    od_roku = YearField()
    do_roku = YearField(null=True, blank=True)
    redaktor = models.ForeignKey("bpp.Autor", CASCADE)

    class Meta:
        app_label = "bpp"
        verbose_name = "redaktor źródła"
        verbose_name_plural = "redaktorzy źródła"

    def __str__(self):
        buf = "Redaktorem od %s " % self.od_roku

        if self.do_roku is not None:
            key = "czas_przeszly"
            buf += "do %s " % self.do_roku
        else:
            key = "czas_terazniejszy"

        if self.redaktor.plec is not None:
            skrot = self.redaktor.plec.skrot
        else:
            skrot = "default"
        buf += czasownik_byc.get(key).get(skrot, czasownik_byc.get(key)["default"])

        buf += " " + str(self.redaktor)
        return buf


# TODO: sprawdzanie dla redakcja_zrodla, czy rok od jest > niz rok do <
class Punktacja_Zrodla(ModelPunktowanyBaza, ModelZKwartylami, models.Model):
    """Informacja o punktacji danego źródła w danym roku"""

    zrodlo = models.ForeignKey("Zrodlo", CASCADE)
    rok = YearField()

    def __str__(self):
        return f'Punktacja źródła "{self.zrodlo}" za rok {self.rok}'

    class Meta:
        verbose_name = "punktacja źródła"
        verbose_name_plural = "punktacja źródła"
        ordering = ["zrodlo__nazwa", "rok"]
        unique_together = [("zrodlo", "rok")]
        app_label = "bpp"


class Dyscyplina_Zrodla(models.Model):
    zrodlo = models.ForeignKey("Zrodlo", on_delete=CASCADE)
    dyscyplina = models.ForeignKey("Dyscyplina_Naukowa", on_delete=CASCADE)

    class Meta:
        verbose_name = "przypisanie dyscypliny do źródła"
        verbose_name_plural = "przypisanie dyscyplin do źródła"
        ordering = ["zrodlo__nazwa", "dyscyplina__nazwa"]
        unique_together = [("zrodlo", "dyscyplina")]
        app_label = "bpp"

    def __str__(self):
        return f'Przypisanie dyscypliny "{self.dyscyplina}" do źródła "{self.zrodlo}"'


class ZrodloManager(FulltextSearchMixin, models.Manager):
    pass


class Zrodlo(LinkDoPBNMixin, ModelZAdnotacjami, ModelZISSN):
    url_do_pbn = const.LINK_PBN_DO_ZRODLA

    nazwa = models.CharField(max_length=1024, db_index=True)
    skrot = models.CharField("Skrót", max_length=512, db_index=True)

    rodzaj = models.ForeignKey(Rodzaj_Zrodla, CASCADE)

    nazwa_alternatywna = models.CharField(
        max_length=1024, db_index=True, blank=True, null=True
    )
    skrot_nazwy_alternatywnej = models.CharField(
        max_length=512, blank=True, null=True, db_index=True
    )

    zasieg = models.ForeignKey(
        Zasieg_Zrodla, SET_NULL, null=True, blank=True, default=None
    )

    www = models.URLField("WWW", max_length=1024, blank=True, null=True, db_index=True)

    doi = DOIField("DOI", blank=True, null=True, db_index=True)

    poprzednia_nazwa = models.CharField(
        "Poprzedni tytuł", max_length=1024, db_index=True, blank=True, null=True
    )

    openaccess_tryb_dostepu = models.CharField(
        verbose_name="OpenAccess: tryb dostępu",
        max_length=50,
        db_index=True,
        blank=True,
        choices=[("FULL", "pełny"), ("PARTIAL", "częściowy")],
    )

    openaccess_licencja = models.ForeignKey(
        "Licencja_OpenAccess",
        CASCADE,
        verbose_name="OpenAccess: licencja",
        blank=True,
        null=True,
    )

    jezyk = models.ForeignKey(Jezyk, CASCADE, null=True, blank=True)
    wydawca = models.CharField(max_length=250, blank=True)

    search = VectorField()

    objects = ZrodloManager()

    pbn_uid = models.ForeignKey(
        "pbn_api.Journal",
        verbose_name="Odpowiednik w PBN",
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
    )

    slug = AutoSlugField(populate_from="nazwa", unique=True)

    def get_absolute_url(self):
        return reverse("bpp:browse_zrodlo", args=(self.slug,))

    def __str__(self):
        ret = "%s" % self.nazwa

        # if self.nazwa_alternatywna:
        #     ret += " (%s)" % self.nazwa_alternatywna
        #
        if self.poprzednia_nazwa:
            ret += " (d. %s)" % (self.poprzednia_nazwa)

        return ret

    class Meta:
        verbose_name = "źródło"
        verbose_name_plural = "źródła"
        ordering = ["nazwa"]
        app_label = "bpp"

    def prace_w_latach(self):
        from bpp.models import Wydawnictwo_Ciagle

        return (
            Wydawnictwo_Ciagle.objects.filter(zrodlo=self)
            .values_list("rok", flat=True)
            .distinct()
            .order_by("rok")
        )



# https://publikacje.up.lublin.pl/pbn_api/callback?ott=dc37f06a-30bd-445a-80bd-199745f65d62


from django.urls import path

from .views import TokenLandingPage, TokenRedirectPage

app_name = "pbn_api"

urlpatterns = [
    path("callback", TokenLandingPage.as_view(), name="callback"),
    path("authorize", TokenRedirectPage.as_view(), name="authorize"),
]



import urllib
from urllib.parse import urlencode

from django.http import HttpResponseRedirect
from django.urls import reverse
from django.views.generic import FormView
from django_filters.views import FilterView
from django_tables2 import SingleTableMixin

from formdefaults.helpers import FormDefaultsMixin
from nowe_raporty.views import BaseRaportAuthMixin
from raport_slotow.filters import RaportSlotowUczelniaEwaluacjaFilter
from raport_slotow.forms import ParametryRaportSlotowEwaluacjaForm
from raport_slotow.models import RaportEwaluacjaUpowaznieniaView
from raport_slotow.tables import RaportEwaluacjaUpowaznieniaTable
from raport_slotow.util import MyExportMixin

from django.utils import timezone

from django_bpp.version import VERSION


class ParametryRaportEwaluacjaUpowaznienia(
    BaseRaportAuthMixin,
    FormDefaultsMixin,
    FormView,
):
    template_name = "raport_slotow/index.html"
    form_class = ParametryRaportSlotowEwaluacjaForm
    uczelnia_attr = "pokazuj_raport_slotow_uczelnia"
    title = "Raport ewaluacja upoważnienia"

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context["title"] = self.title
        return context

    def form_valid(self, form):
        return HttpResponseRedirect(
            reverse(
                "raport_slotow:raport-ewaluacja-upowaznienia",
            )
            + "?"
            + urlencode(form.cleaned_data)
        )


class RaportEwaluacjaUpowaznienia(
    BaseRaportAuthMixin, MyExportMixin, SingleTableMixin, FilterView
):
    template_name = "raport_slotow/raport_ewaluacja_upowaznienia.html"
    table_class = RaportEwaluacjaUpowaznieniaTable
    uczelnia_attr = "pokazuj_raport_slotow_uczelnia"
    export_formats = ["html", "xlsx"]
    filterset_class = RaportSlotowUczelniaEwaluacjaFilter

    def get_form(self, dct):
        return ParametryRaportSlotowEwaluacjaForm(dct)

    def get(self, request, *args, **kw):
        form = self.get_form(request.GET)

        if form.is_valid():
            self.data = form.cleaned_data
            if self.data["upowaznienie_pbn"] == "":
                self.data["upowaznienie_pbn"] = None

            return super().get(self.request, *args, **kw)
        else:
            return self.form_invalid(form)

    def form_invalid(self, form):
        return HttpResponseRedirect("..")

    def get_export_description(self):
        return [
            ("Nazwa raportu:", "raport ewaluacja upoważnienia"),
            ("Od roku:", self.data["od_roku"]),
            ("Do roku:", self.data["do_roku"]),
            ("Upoważnienie PBN:", self.data["upowaznienie_pbn"]),
            ("Wygenerowano:", str(timezone.now())),
            ("Wersja oprogramowania BPP", VERSION),
        ]

    def get_queryset(self):
        upowaznienie_kw = {}
        if self.data.get("upowaznienie_pbn") is not None:
            upowaznienie_kw["autorzy__upowaznienie_pbn"] = self.data["upowaznienie_pbn"]

        return RaportEwaluacjaUpowaznieniaView.objects.filter(
            rekord__rok__gte=self.data["od_roku"],
            rekord__rok__lte=self.data["do_roku"],
            **upowaznienie_kw,
        ).select_related(
            "autorzy",
            "rekord",
            "autorzy__dyscyplina_naukowa",
            "autorzy__autor__aktualna_jednostka",
            "autorzy__autor__tytul",
            "rekord__charakter_formalny",
            "rekord__typ_kbn",
            "autorzy__autor__aktualna_jednostka__wydzial",
            "rekord__zrodlo",
            "rekord__wydawnictwo_nadrzedne",
            "autor_dyscyplina",
            "rekord__charakter_formalny",
            "autorzy__autor",
            "autor_dyscyplina__dyscyplina_naukowa",
            "autor_dyscyplina__subdyscyplina_naukowa",
        )

    def get_context_data(self, *, object_list=None, **kwargs):
        context = super().get_context_data(**kwargs)
        context["od_roku"] = self.data["od_roku"]
        context["do_roku"] = self.data["do_roku"]
        context["export_link"] = urllib.parse.urlencode(
            dict(
                self.request.GET,
                **{
                    "_export": "xlsx",
                    "od_roku": self.data["od_roku"],
                    "do_roku": self.data["do_roku"],
                    "upowaznienie_pbn": self.data["upowaznienie_pbn"],
                },
            ),
            doseq=True,
        )

        return context

    def get_export_filename(self, export_format):
        return f"raport_ewaluacjA_upowaznienia_{self.data['od_roku']}-{self.data['do_roku']}.{export_format}"



import django_filters
from django.forms import NumberInput, TextInput

from bpp.models import Autorzy, Cache_Punktacja_Autora_Sum_Gruop, Dyscyplina_Naukowa


class RaportSlotowUczelniaBezJednostekIWydzialowFilter(django_filters.FilterSet):
    autor__nazwisko = django_filters.CharFilter(
        lookup_expr="icontains",
        widget=TextInput(attrs={"placeholder": "Podaj nazwisko"}),
    )

    dyscyplina = django_filters.ModelChoiceFilter(
        queryset=Dyscyplina_Naukowa.objects.filter(
            pk__in=Autorzy.objects.values("dyscyplina_naukowa_id").distinct()
        )
    )

    slot__min = django_filters.NumberFilter(
        "slot",
        lookup_expr="gte",
        widget=NumberInput(attrs={"placeholder": "min"}),
    )

    slot__max = django_filters.NumberFilter(
        "slot",
        lookup_expr="lte",
        widget=NumberInput(attrs={"placeholder": "max"}),
    )

    avg__min = django_filters.NumberFilter(
        "avg", lookup_expr="gte", widget=NumberInput(attrs={"placeholder": "min"})
    )

    avg__max = django_filters.NumberFilter(
        "avg", lookup_expr="lte", widget=NumberInput(attrs={"placeholder": "max"})
    )

    class Meta:
        model = Cache_Punktacja_Autora_Sum_Gruop
        fields = ["autor__nazwisko", "dyscyplina__nazwa"]


class RaportSlotowUczelniaFilter(RaportSlotowUczelniaBezJednostekIWydzialowFilter):
    suma__min = django_filters.NumberFilter(
        "pkd_aut_sum",
        lookup_expr="gte",
        widget=NumberInput(attrs={"placeholder": "min"}),
    )

    suma__max = django_filters.NumberFilter(
        "pkd_aut_sum",
        lookup_expr="lte",
        widget=NumberInput(attrs={"placeholder": "max"}),
    )

    class Meta:
        model = Cache_Punktacja_Autora_Sum_Gruop
        fields = ["autor__nazwisko", "suma__min", "suma__max"]


class RaportZerowyFilter(django_filters.FilterSet):
    autor__nazwisko = django_filters.CharFilter(
        lookup_expr="icontains",
        widget=TextInput(attrs={"placeholder": "Podaj nazwisko"}),
    )
    rok__min = django_filters.NumberFilter(
        "rok",
        lookup_expr="gte",
        widget=NumberInput(attrs={"placeholder": "min"}),
    )

    rok__max = django_filters.NumberFilter(
        "rok",
        lookup_expr="lte",
        widget=NumberInput(attrs={"placeholder": "max"}),
    )
    dyscyplina_naukowa = django_filters.ModelChoiceFilter(
        queryset=Dyscyplina_Naukowa.objects.filter(
            pk__in=Autorzy.objects.values("dyscyplina_naukowa_id").distinct()
        )
    )


class RaportSlotowUczelniaEwaluacjaFilter(django_filters.FilterSet):
    autorzy__autor__nazwisko = django_filters.CharFilter(
        lookup_expr="icontains",
        widget=TextInput(attrs={"placeholder": "Podaj nazwisko"}),
    )

    autorzy__dyscyplina_naukowa = django_filters.ModelChoiceFilter(
        queryset=Dyscyplina_Naukowa.objects.all()
    )
